@@ -1,4 +1,4 @@
 #!/bin/sh
 
 /scripts/add_default_route.sh &
-exec /UERANSIM/build/nr-ue $*
+exec /UERANSIM/build/nr-ue "$@"
