@@ -1,3 +1,3 @@
 def main():
     from daedalus.daedalus import Daedalus
-    Daedalus()
+    Daedalus().main()
