@@ -20,7 +20,7 @@ from examples import custom_style_2
 from plumbum import FG  # pytype: disable=import-error
 from plumbum import local  # pytype: disable=import-error
 from plumbum import TF  # pytype: disable=import-error
-from plumbum.cmd import chmod  # pytype: disable=import-error
+from plumbum.cmd import chown  # pytype: disable=import-error
 from plumbum.cmd import cp  # pytype: disable=import-error
 from plumbum.cmd import curl  # pytype: disable=import-error
 from plumbum.cmd import docker  # pytype: disable=import-error
@@ -76,17 +76,14 @@ class Daedalus():
             version = 'v'+__version__
 
         if srsran:
-            srsran_version = 'release_21_04'
-            base_args = ['build', '-t', 'iqtlabs/srsran-base:'+version,
-                         '-f', 'Dockerfile.base', '.']
-            srs_args = ['build', '-t', 'iqtlabs/srsran:'+version, '-f', 'Dockerfile.srs',
+            srsran_version = 'release_21_10'
+            srs_args = ['build', '-t', 'iqtlabs/srsran:'+version, '-f', 'Dockerfile',
                         '--build-arg', f'SRS_VERSION={srsran_version}', '.']
             with local.cwd(local.cwd / 'srsRAN'):
-                docker.bound_command(base_args) & FG
                 docker.bound_command(srs_args) & FG
         if srsran_lime:
             srsran_version = 'release_19_12'
-            srs_args = ['build', '-t', 'iqtlabs/srsran-lime:'+version, '-f', 'Dockerfile.srs',
+            srs_args = ['build', '-t', 'iqtlabs/srsran-lime:'+version, '-f', 'Dockerfile',
                         '--build-arg', f'SRS_VERSION={srsran_version}', '.']
             with local.cwd(local.cwd / 'srsRAN'):
                 docker.bound_command(srs_args) & FG
@@ -101,7 +98,7 @@ class Daedalus():
 
     def start_dovesnap(self):
         """Start Dovesnap components in Docker containers"""
-        release = 'v1.0.1'
+        release = 'v1.0.4'
         faucet_prefix = '/tmp/tpfaucet'
         sudo[ip['link', 'add', 'tpmirrorint', 'type', 'veth',
                 'peer', 'name', 'tpmirror']](retcode=(0, 2))
@@ -480,7 +477,7 @@ class Daedalus():
         """
         logging.info(
             'Checking necessary commands exist, if it fails, install the missing tools.')
-        chmod['--version']()
+        chown['--version']()
         cp['--version']()
         curl['--version']()
         docker['--version']()
@@ -512,12 +509,23 @@ class Daedalus():
                     running = False
 
     @staticmethod
-    def set_config_dir(conf_dir='/5G'):
+    def _check_conf_dir(conf_dir):
+        realpath = os.path.realpath(conf_dir)
+        if not realpath.endswith('/5G'):
+            raise ValueError(
+                'last element of conf_dir must be 5G: %s' % realpath)
+        for valid_prefix in ('/usr/local', '/opt', '/home'):
+            if realpath.startswith(valid_prefix):
+                return realpath
+        raise ValueError('conf_dir root may not be safe: %s' % realpath)
+
+    def set_config_dir(self, conf_dir='/5G'):
         """Set the current working directory to where the configs are"""
         try:
-            os.chdir(os.path.dirname(__file__).split('lib')[0] + conf_dir)
-            # TODO find a better way to do this for writing out dovesnap files
-            sudo[chmod['-R', '777', '.']]()
+            realpath = self._check_conf_dir(
+                os.path.dirname(__file__).split('lib')[0] + conf_dir)
+            os.chdir(realpath)
+            sudo[chown['-R', str(os.getuid()), '.']]()
         except Exception as err:  # pragma: no cover
             logging.error(
                 'Unable to find config files, exiting because: %s', err)
@@ -525,8 +533,6 @@ class Daedalus():
 
     def reset_cwd(self):
         """Set the current working directory back to what it was originally"""
-        # TODO find a better way to do this for writing out dovesnap files
-        sudo[chmod['-R', '755', '.']]()
         os.chdir(self.previous_dir)
 
     def parse_answers(self, answers):
